package control;

import vehicle.Vehicle;

public interface BridgeControl {

	/**
	 * This method is called once after the object has been initialized.
	 * 
	 * @param maxLoad	Max load (depending on users input) 
	 */
	public void init(Double maxLoad);
	
	
	/**
	 * Every time a vehicle wants to cross the bridge, it will call this method.
	 * As long as this method remains blocking, the vehicle will stay waiting.
	 * Once the method terminates, the vehicle will start to cross the bridge.
	 * 
	 * @param v		Vehicle asking for the permission to cross the bridge.
	 */
	public void requestCrossing(Vehicle v);
	
	/**
	 * Every time a vehicle leaves the bridge, it will call this method in order
	 * to inform the BridgeControl. The vehicle couldn't be blocked by blocking
	 * this method.
	 * 
	 * @param v		Vehicle finished the crossing
	 */
	public void leaveBridge(Vehicle v);
	
}
