package fx;

import java.io.IOException;

import fx.animation.AnimationController;
import fx.options.OptionsController;
import javafx.application.Application;
import javafx.event.EventHandler;
import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Tab;
import javafx.scene.control.TabPane;
import javafx.stage.Stage;
import javafx.stage.WindowEvent;

/**
 * @author Thierry Meurers
 *
 * Entry point of the Accross the Bridge Framework.
 */
public class BridgeFX extends Application {


	/**
	 * All the classes listed in the mutexClasses array will be displayed in the
	 * ComboBox (in the Options Tab). By pressing the (Re)Start button, the
	 * selected class will be loaded using the reflection api.
	 */
	final static private String[] mutexClasses = {"control.OnlyWestBC"};


	public static void main(String[] args) {
		launch(args);
	}
	
	/**
	 * Creates the TabPane and initializes the two Tabs before showing the stage.
	 */
	public void start(Stage primaryStage) {

		// Initialize the Options Tab ***********************
		FXMLLoader loader = new FXMLLoader(getClass().getResource("options/BridgeOptions.fxml"));

		Parent root = null;
		try {
			root = (((Parent) loader.load()));
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		Tab optionsTab = new Tab(" Options ");
		optionsTab.setContent(root);
		optionsTab.setClosable(false);

		
		OptionsController optionsController = loader.getController();
		optionsController.setMutexClasses(mutexClasses);
		optionsController.readOptions();
		
		
		// Initialize the Animation Tab *********************
		AnimationController animationController = new AnimationController(optionsController);
		
		Tab animationTab = new Tab("Animation");
		animationTab.setContent(animationController.getView());
		animationTab.setClosable(false);

		// Create and fill the TabPane **********************
		TabPane tabPane = new TabPane();
		tabPane.getTabs().addAll(animationTab, optionsTab);
		
		// Set scene to Stage and show the stage ************
		Scene scene = new Scene(tabPane, 999, 600);
		scene.getStylesheets().add("fx/Themen.css");
		primaryStage.setScene(scene);
		primaryStage.setResizable(false);
		primaryStage.sizeToScene();
		primaryStage.setTitle("Across the Bridge (v1.0)");
		primaryStage.show();

		//Whenever the stage is closed -> save all options and close all info dialogs.
		primaryStage.setOnCloseRequest(new EventHandler<WindowEvent>() {
			public void handle(WindowEvent we) {
				optionsController.saveOptions();
				animationController.closeInfoDialogs();
			}
		});
	}

}
