package fx.animation;

import javafx.geometry.Insets;
import javafx.scene.Group;
import javafx.scene.control.Button;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;
import javafx.scene.text.Text;

/**
 * @author Thierry Meurers
 *
 * This class defines how the Animation Tab looks. All components are
 * created, styled and assigned to the GUI.
 * Furthermore get-Methods and methods to change the value of the Texts
 * are provided.
 */
public class AnimationView{
	
	private Pane root;
	
	private Group dynamicShapes;
	private Group vehicleShapes, textShapes;
	
	private Text loadTXT, overloadTXT, framesTXT, scoreTXT, score2TXT;
	private Rectangle bridgeRECT;
	
	private Button startBTN;

	AnimationView() {
		root = new Pane();

		Pane uiControls = drawUiControls();
		Group staticShapes = drawStaticShapes();
		dynamicShapes = prepareDynamicShapes();
		
		root.getChildren().addAll(staticShapes, dynamicShapes, uiControls);
		root.setId("animationPane");
	}
	
	
	private Group drawStaticShapes() {
		Rectangle westCoast, eastCoast, background;
		background = new Rectangle(0, 0, 1000, 600);
		westCoast = new Rectangle(0, 300, 300, 300);
		eastCoast = new Rectangle(700, 300, 300, 300);
		bridgeRECT = new Rectangle(300, 300, 400, 8);

		background.setFill(Color.TRANSPARENT);
		westCoast.setFill(Color.GREEN);
		eastCoast.setFill(Color.GREEN);
		bridgeRECT.setFill(Color.ORANGE);

		return new Group(background, westCoast, eastCoast, bridgeRECT);
	}

	private Pane drawUiControls() {
		
		HBox hBox = new HBox();

		startBTN = new Button("(Re)Start");
		startBTN.setStyle("-fx-font: 18 verdana; -fx-base: #b6e7c9;");

		hBox.getChildren().addAll(startBTN);

		hBox.setPadding(new Insets(10, 10, 10, 10));
		hBox.setSpacing(10);

		return hBox;
	}
	
	private Group prepareDynamicShapes(){
		vehicleShapes = new Group();
		textShapes = new Group();
		
		this.scoreTXT = createText(1.8, Color.DEEPPINK, 20.0);
		this.score2TXT = createText(1.2, Color.BLACK, 40.0);
		this.loadTXT = createText(2.0, Color.BLACK, 250.0);
		this.overloadTXT = createText(3.0, Color.RED, 200.0);
		this.framesTXT = createText(1.1, Color.BLACK, 20.0);
		
		textShapes.getChildren().addAll(scoreTXT, score2TXT, loadTXT, overloadTXT, framesTXT);
		
		return new Group(textShapes, vehicleShapes);
	}
	
	private Text createText(Double size, Color clr, Double y) {
		Text tmp = new Text();
		tmp.setFill(clr);
		tmp.setScaleX(size);
		tmp.setScaleY(size);
		tmp.setY(y);
		return tmp;
	}
	
	public void resetAnimation(){
		scoreTXT.setText("");
		score2TXT.setText("");
		overloadTXT.setText("");
		framesTXT.setText("");
		loadTXT.setText("");
		
		bridgeRECT.setFill(Color.ORANGE);
		
		vehicleShapes.getChildren().clear();

	}

	public void hideBridgeRECT(){
		bridgeRECT.setFill(Color.TRANSPARENT);
	}

	public Group getVehicleShapes() {
		return vehicleShapes;
	}

	public Button getStartBTN() {
		return startBTN;
	}
	
	public Pane getRoot(){
		return root;
	}
	
	public void setLoadTXTcontent(String text){
		loadTXT.setText(text);
		loadTXT.setX(500 - loadTXT.getLayoutBounds().getWidth() / 2);
	}
	
	public void setScoreTXTcontent(String text){
		scoreTXT.setText(text);
		scoreTXT.setX(500 - scoreTXT.getLayoutBounds().getWidth() / 2);
	}
	
	public void setScore2TXTcontent(String text){
		score2TXT.setText(text);
		score2TXT.setX(500 - score2TXT.getLayoutBounds().getWidth() / 2);
	}
	
	public void setOverloadTXTcontent(String text){
		overloadTXT.setText(text);
		overloadTXT.setX(500 - overloadTXT.getLayoutBounds().getWidth() / 2);
	}
	
	public void setFramesTXTcontent(String text){
		framesTXT.setText(text);
		framesTXT.setX(990 - framesTXT.getLayoutBounds().getWidth());
	}
	

}
